// Copyright (c) 2017, A. Stoewer <adrian.stoewer@rz.ifi.lmu.de>
// All rights reserved.

// Package strcase converts between different kinds of naming formats such as camel case
// (CamelCase), snake case (snake_case) or kebab case (kebab-case). The package is designed
// to work only with strings consisting of standard ASCII letters. Unicode is currently not
// supported.
package strcase
